==> navigation-react-4.9.0.tgz: package/NavigationHandler.js <==
'use client';
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import React, { Component } from 'react';
import AsyncStateNavigator from './AsyncStateNavigator.js';
import NavigationContext from './NavigationContext.js';
var NavigationHandler = /** @class */ (function (_super) {
    __extends(NavigationHandler, _super);
    function NavigationHandler(props) {
        var _this = _super.call(this, props) || this;
        var stateNavigator = _this.props.stateNavigator;
        var _a = stateNavigator.stateContext, oldState = _a.oldState, state = _a.state, data = _a.data, asyncData = _a.asyncData;
        var asyncNavigator = new AsyncStateNavigator(_this, stateNavigator, stateNavigator.stateContext);
        _this.state = { context: { oldState: oldState, state: state, data: data, asyncData: asyncData, stateNavigator: asyncNavigator } };
        _this.onNavigate = _this.onNavigate.bind(_this);
        return _this;
    }
    NavigationHandler.prototype.componentDidMount = function () {
        this.props.stateNavigator.onNavigate(this.onNavigate);
    };
    NavigationHandler.prototype.componentWillUnmount = function () {
        this.props.stateNavigator.offNavigate(this.onNavigate);
    };
    NavigationHandler.prototype.onNavigate = function () {
        var _this = this;
        var stateNavigator = this.props.stateNavigator;
        var stateContext = stateNavigator.stateContext;
        if (this.state.context.stateNavigator.stateContext !== stateContext) {
            var history_1 = stateContext.history, oldState_1 = stateContext.oldState, state_1 = stateContext.state, data_1 = stateContext.data, asyncData_1 = stateContext.asyncData;
            var asyncNavigator_1 = new AsyncStateNavigator(this, stateNavigator, stateContext);
            var startTransition_1 = React.startTransition || (function (transition) { return transition(); });
            this.setState({ context: { oldState: oldState_1, state: state_1, data: data_1, asyncData: asyncData_1, stateNavigator: asyncNavigator_1 } }, function () {
                if (stateNavigator.stateContext === stateContext && history_1) {
                    startTransition_1(function () {
                        _this.setState({ context: { ignoreCache: true, oldState: oldState_1, state: state_1, data: data_1, asyncData: asyncData_1, stateNavigator: asyncNavigator_1 } });
                    });
                }
            });
        }
    };
    NavigationHandler.prototype.render = function () {
        return (React.createElement(NavigationContext.Provider, { value: this.state.context }, this.props.children));
    };
    return NavigationHandler;
}(Component));
export default NavigationHandler;

==> navigation-react-4.12.0.tgz: package/NavigationHandler.js <==
'use client';
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { Component, startTransition } from 'react';
import AsyncStateNavigator from './AsyncStateNavigator.js';
import NavigationContext from './NavigationContext.js';
import SceneRSCContext from './SceneRSCContext.js';
var NavigationHandler = /** @class */ (function (_super) {
    __extends(NavigationHandler, _super);
    function NavigationHandler(props) {
        var _this = _super.call(this, props) || this;
        var stateNavigator = _this.props.stateNavigator;
        var _a = stateNavigator.stateContext, oldState = _a.oldState, state = _a.state, data = _a.data, asyncData = _a.asyncData;
        var asyncNavigator = new AsyncStateNavigator(_this, stateNavigator, stateNavigator.stateContext);
        _this.state = { context: { oldState: oldState, state: state, data: data, asyncData: asyncData, stateNavigator: asyncNavigator } };
        _this.onNavigate = _this.onNavigate.bind(_this);
        _this.refetch = _this.refetch.bind(_this);
        return _this;
    }
    NavigationHandler.prototype.componentDidMount = function () {
        this.props.stateNavigator.onNavigate(this.onNavigate);
    };
    NavigationHandler.prototype.componentWillUnmount = function () {
        this.props.stateNavigator.offNavigate(this.onNavigate);
    };
    NavigationHandler.prototype.onNavigate = function () {
        var stateNavigator = this.props.stateNavigator;
        var stateContext = stateNavigator.stateContext;
        if (this.state.context.stateNavigator.stateContext !== stateContext) {
            var oldState = stateContext.oldState, state = stateContext.state, data = stateContext.data, asyncData = stateContext.asyncData;
            var asyncNavigator = new AsyncStateNavigator(this, stateNavigator, stateContext);
            this.setState({ context: { oldState: oldState, state: state, data: data, asyncData: asyncData, stateNavigator: asyncNavigator } });
        }
    };
    NavigationHandler.prototype.refetch = function () {
        var _this = this;
        startTransition(function () {
            _this.setState({ context: __assign(__assign({}, _this.state.context), { ignoreCache: true }) });
        });
    };
    NavigationHandler.prototype.render = function () {
        return (React.createElement(NavigationContext.Provider, { value: this.state.context },
            React.createElement(SceneRSCContext.Provider, { value: this.refetch }, this.props.children)));
    };
    return NavigationHandler;
}(Component));
export default NavigationHandler;
